#!/usr/bin/env python
"""Django's command-line utility for administrative tasks."""
import os
import sys


def startDjango():
    sys.path.insert(0, os.getcwd())  # Import project to PYTHONPATH
    try:
        from django.core.management import execute_from_command_line
    except ImportError as exc:
        raise ImportError(
            "Couldn't import Django. Are you sure it's installed and "
            "available on your PYTHONPATH environment variable? Did you "
            "forget to activate a virtual environment?"
        ) from exc
    execute_from_command_line(sys.argv)


def main():
    os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'tipboard.webserver.settings')
    startDjango()


# to become a pacakage and go to pypi :)
def main_as_pkg():
    os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'src.tipboard.webserver.settings')
    startDjango()


if __name__ == '__main__':
    main()


